Convert ocean numerical models grids to geo-like objects
========================================================


``gridgeo`` Convert ocean numerical models grids,
including UGRID and SGRID compliant files,
to a variety of geo-like objects: GeoJSON, and shapefile.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   gridgeo_tour-output.ipynb
   gridgeo

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
